dayMonth property
String
get
dayMonth
Formats the current number as a date string in 'dd-MM' format.
Implementation
String get dayMonth => DateFormats.dayMonth.format(toDateTime);
Formats the current number as a date string in 'dd-MM' format.
String get dayMonth => DateFormats.dayMonth.format(toDateTime);