hm property
String
get
hm
Formats the current number as a time string in 'HH:mm' format.
Implementation
String get hm => DateFormats.hm.format(toDateTime);
Formats the current number as a time string in 'HH:mm' format.
String get hm => DateFormats.hm.format(toDateTime);