shortDate property
String
get
shortDate
Formats the current number as a short date string, which is locale dependent.
Implementation
String get shortDate => DateFormats.shortDate.format(toDateTime);
Formats the current number as a short date string, which is locale dependent.
String get shortDate => DateFormats.shortDate.format(toDateTime);