time property
String
get
time
Formats the current number as a time string in 'HH:mm:ss' format.
Implementation
String get time => DateFormats.time.format(toDateTime);
Formats the current number as a time string in 'HH:mm:ss' format.
String get time => DateFormats.time.format(toDateTime);