yearMonth property
String
get
yearMonth
Formats the current number as a date string in 'yyyy-MM' format.
Implementation
String get yearMonth => DateFormats.yearMonth.format(toDateTime);
Formats the current number as a date string in 'yyyy-MM' format.
String get yearMonth => DateFormats.yearMonth.format(toDateTime);