StringCustomFunctionExtensions extension

String common function extensions

on

Properties

capitalize String

Available on String, provided by the StringCustomFunctionExtensions extension

Capitalizes the first letter of the string. Returns the original string if it is empty.
no setter
removeAllSpaces String

Available on String, provided by the StringCustomFunctionExtensions extension

Removes all spaces from the string.
no setter
reversed String

Available on String, provided by the StringCustomFunctionExtensions extension

Reverses the string.
no setter
toCamelCase String

Available on String, provided by the StringCustomFunctionExtensions extension

Converts the string to camelCase.
no setter
toKebabCase String

Available on String, provided by the StringCustomFunctionExtensions extension

Converts the string to kebab-case.
no setter
toSnakeCase String

Available on String, provided by the StringCustomFunctionExtensions extension

Converts the string to snake_case.
no setter
toTitleCase String

Available on String, provided by the StringCustomFunctionExtensions extension

Converts the string to Title Case.
no setter

Methods

insert(int index, String str) String

Available on String, provided by the StringCustomFunctionExtensions extension

Inserts the string str at the specified index within the original string. Throws RangeError if index is out of bounds.
limit(int count, {String suffix = '...'}) String

Available on String, provided by the StringCustomFunctionExtensions extension

Limits the string length to count and adds optional suffix.
onEmpty(String? val) String?

Available on String, provided by the StringCustomFunctionExtensions extension

Returns a provided alternative string val if the original string is empty. If val is null, it defaults to an empty string.
removePrefix(String prefix) String

Available on String, provided by the StringCustomFunctionExtensions extension

Removes the given prefix from the start of the string if it exists.
removeSuffix(String suffix) String

Available on String, provided by the StringCustomFunctionExtensions extension

Removes the given suffix from the end of the string if it exists.
repeat(int times) String

Available on String, provided by the StringCustomFunctionExtensions extension

Repeats the string times number of times.
replaceFirst(String from, String replace) String

Available on String, provided by the StringCustomFunctionExtensions extension

Replaces the first occurrence of the substring from with replace. If from is not found in the string, returns the original string.
replaceLast(String from, String to) String

Available on String, provided by the StringCustomFunctionExtensions extension

Replaces the last occurrence of the substring from with to. If from is not found in the string, returns the original string.
safeSubstring(int startIndex, int endIndex) String

Available on String, provided by the StringCustomFunctionExtensions extension

Safely substrings the string, if the string length is not enough, return the original string.
substringAfter(String delimiter, {String? missingDelimiterValue}) String

Available on String, provided by the StringCustomFunctionExtensions extension

Returns a substring after the first occurrence of delimiter.
substringBefore(String delimiter, {String? missingDelimiterValue}) String

Available on String, provided by the StringCustomFunctionExtensions extension

Returns a substring before the first occurrence of delimiter.
toEnum<T>(List<T> enumValues) → T?

Available on String, provided by the StringCustomFunctionExtensions extension

Tries to parse the string into a specified enum type T. Returns null if the parsing fails. This method requires the list of all enum values enumValues to check against.
truncate(int max, {String suffix = '...'}) String

Available on String, provided by the StringCustomFunctionExtensions extension

Truncates the string to a maximum of max characters and adds a suffix if truncated.