DateTimeExtensions extension
DateTime common extensions
- on
Properties
- daysInMonth → int
-
Available on DateTime, provided by the DateTimeExtensions extension
Returns the number of days in the month of this date.no setter - endOfDay → DateTime
-
Available on DateTime, provided by the DateTimeExtensions extension
Returns the end of the day for this DateTime object.no setter - isLeapYear → bool
-
Available on DateTime, provided by the DateTimeExtensions extension
Checks if the year of this date is a leap year.no setter - isToday → bool
-
Available on DateTime, provided by the DateTimeExtensions extension
Checks if this date is today.no setter - isTomorrow → bool
-
Available on DateTime, provided by the DateTimeExtensions extension
Checks if this date is tomorrow.no setter - isWeekend → bool
-
Available on DateTime, provided by the DateTimeExtensions extension
Checks if the given date is on a weekend.no setter - isYesterday → bool
-
Available on DateTime, provided by the DateTimeExtensions extension
Checks if this date is yesterday.no setter - nextDay → DateTime
-
Available on DateTime, provided by the DateTimeExtensions extension
Returns the date of the next day.no setter - previousDay → DateTime
-
Available on DateTime, provided by the DateTimeExtensions extension
Returns the date of the previous day.no setter - startOfDay → DateTime
-
Available on DateTime, provided by the DateTimeExtensions extension
Returns the start of the day for this DateTime object.no setter
Methods
-
addBusinessDays(
int count) → DateTime -
Available on DateTime, provided by the DateTimeExtensions extension
Adds a specified number of business days, skipping weekends. -
isSameDay(
DateTime other) → bool -
Available on DateTime, provided by the DateTimeExtensions extension
Determines whether twoDateTimeobjects are on the same day. -
isSameMonth(
DateTime other) → bool -
Available on DateTime, provided by the DateTimeExtensions extension
Checks if this date is in the same month asother. -
isSameYear(
DateTime other) → bool -
Available on DateTime, provided by the DateTimeExtensions extension
Checks if this date is in the same year asother. -
subtractBusinessDays(
int count) → DateTime -
Available on DateTime, provided by the DateTimeExtensions extension
Subtracts a specified number of business days, skipping weekends.