DecimalMoneyExtensions extension
Decimal money formatting extensions
- on
-
- Decimal
Methods
-
formatMoney(
{String symbol = '', int decimalDigits = 2}) → String -
Available on Decimal, provided by the DecimalMoneyExtensions extension
Formats theDecimalas a money string with custom prefix, thousand separators and a specified number of decimal places. -
toMoney(
{int decimalDigits = 2}) → String -
Available on Decimal, provided by the DecimalMoneyExtensions extension
Formats theDecimalas a money string with thousand separators and a specified number of decimal places.