ObjectExtensions<T extends Object> extension
Extension methods for Object to provide common utility functions.
- on
-
- T
Methods
-
also(
void f(T)) → T -
Available on T, provided by the ObjectExtensions extension
Calls the specified functionfwith as its argument and returnsthis. -
let<
R> (R f(T)) → R -
Available on T, provided by the ObjectExtensions extension
Calls the specified functionfwith as its argument and returns the result.